﻿//
// Lightbox Gallery Module for DotNetNuke
// Project Contributors - Will Strohl (http://www.WillStrohl.com), Armand Datema (http://www.schwingsoft.com)
//
//Copyright (c) 2009-2013, Will Strohl
//All rights reserved.
//
//Redistribution and use in source and binary forms, with or without modification, are 
//permitted provided that the following conditions are met:
//
//Redistributions of source code must retain the above copyright notice, this list of 
//conditions and the following disclaimer.
//
//Redistributions in binary form must reproduce the above copyright notice, this list 
//of conditions and the following disclaimer in the documentation and/or other 
//materials provided with the distribution.
//
//Neither the name of Will Strohl, Armand Datema, Lightbox Gallery, nor the names of its contributors may be 
//used to endorse or promote products derived from this software without specific prior 
//written permission.
//
//THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY 
//EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
//OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
//SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
//INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
//TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR 
//BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
//CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
//ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
//DAMAGE.
//

//INSTANT C# NOTE: Formerly VB project-level imports:
using System;
using System.Collections.Generic;
using DotNetNuke.Services.Exceptions;

namespace WillStrohl.Modules.Lightbox
{

    public sealed class ImageInfoCollection : List<ImageInfo>
    {

        #region  Constructors

        public ImageInfoCollection()
            : base()
        {
        }

        public ImageInfoCollection(int capacity)
            : base(capacity)
        {
        }

        public ImageInfoCollection(IEnumerable<ImageInfo> collection)
            : base(collection)
        {
        }

        #endregion

        public void Fill(System.Data.IDataReader dr)
        {
            try
            {
                while (dr.Read())
                {
                    var obj = new ImageInfo();
                    if (dr[ImageInfoMembers.ImageIdField] != null)
                    {
                        obj.ImageId = int.Parse(dr[ImageInfoMembers.ImageIdField].ToString(), System.Globalization.NumberStyles.Integer);
                    }
                    if (dr[ImageInfoMembers.LightboxIdField] != null)
                    {
                        obj.LightboxId = int.Parse(dr[ImageInfoMembers.LightboxIdField].ToString(), System.Globalization.NumberStyles.Integer);
                    }
                    if (dr[ImageInfoMembers.FileNameField] != null)
                    {
                        obj.FileName = dr[ImageInfoMembers.FileNameField].ToString();
                    }
                    if (dr[ImageInfoMembers.TitleField] != null)
                    {
                        obj.Title = dr[ImageInfoMembers.TitleField].ToString();
                    }
                    if (dr[ImageInfoMembers.DescriptionField] != null)
                    {
                        obj.Description = dr[ImageInfoMembers.DescriptionField].ToString();
                    }
                    if (dr[ImageInfoMembers.DisplayOrderField] != null)
                    {
                        obj.DisplayOrder = int.Parse(dr[ImageInfoMembers.DisplayOrderField].ToString(), System.Globalization.NumberStyles.Integer);
                    }
                    if (dr[ImageInfoMembers.LastUpdatedByField] != null)
                    {
                        try
                        {
                            obj.LastUpdatedBy = int.Parse(dr[ImageInfoMembers.LastUpdatedByField].ToString(), System.Globalization.NumberStyles.Integer);
                        }
                        catch
                        {
                            // do nothing
                        }
                    }
                    if (dr[ImageInfoMembers.LastUpdatedDateField] != null)
                    {
                        try
                        {
                            obj.LastUpdatedDate = DateTime.Parse(dr[ImageInfoMembers.LastUpdatedDateField].ToString());
                        }
                        catch
                        {
                            obj.LastUpdatedDate = DateTime.Now;
                        }
                    }
                    this.Add(obj);
                }
            }
            catch (Exception ex)
            {
                Exceptions.LogException(ex);
            }
            finally
            {
                if (!dr.IsClosed)
                {
                    dr.Close();
                }
            }
        }

    }

}